[Pcsclite-cvs-commit] r3070 - /trunk/PCSC/src/winscard_clnt.c

rousseau at users.alioth.debian.org rousseau at users.alioth.debian.org
Wed Jul 30 14:05:20 UTC 2008


Author: rousseau
Date: Wed Jul 30 14:05:20 2008
New Revision: 3070

URL: http://svn.debian.org/wsvn/pcsclite/?sc=1&rev=3070
Log:
SCardStatus(): rename parameter mszReaderNames in mszReaderName since it
is the name of one reader only

Modified:
    trunk/PCSC/src/winscard_clnt.c

Modified: trunk/PCSC/src/winscard_clnt.c
URL: http://svn.debian.org/wsvn/pcsclite/trunk/PCSC/src/winscard_clnt.c?rev=3070&op=diff
==============================================================================
--- trunk/PCSC/src/winscard_clnt.c (original)
+++ trunk/PCSC/src/winscard_clnt.c Wed Jul 30 14:05:20 2008
@@ -1444,7 +1444,7 @@
  *
  * @ingroup API
  * @param[in] hCard Connection made from SCardConnect().
  * @param mszReaderNames [inout] Friendly name of this reader.
  * @param pcchReaderLen [inout] Size of the \p szReaderName multistring.
  * @param[out] pdwState Current state of this reader. \p pdwState
  * is a DWORD possibly OR'd with the following values:
@@ -1491,7 +1491,7 @@
  * rv=SCardStatus(hCard, NULL, &dwReaderLen, &dwState, &dwProtocol, pbAtr, &dwAtrLen);
  * @endcode
  */
-LONG SCardStatus(SCARDHANDLE hCard, LPSTR mszReaderNames,
+LONG SCardStatus(SCARDHANDLE hCard, LPSTR mszReaderName,
 	LPDWORD pcchReaderLen, LPDWORD pdwState,
 	LPDWORD pdwProtocol, LPBYTE pbAtr, LPDWORD pcbAtrLen)
 {
@@ -1624,10 +1624,10 @@
 			rv = SCARD_E_NO_MEMORY;
 			goto end;
 		}
-		*(char **)mszReaderNames = bufReader;
+		*(char **)mszReaderName = bufReader;
 	}
 	else
-		bufReader = mszReaderNames;
+		bufReader = mszReaderName;
 
 	/* return SCARD_E_INSUFFICIENT_BUFFER only if buffer pointer is non NULL */
 	if (bufReader)
@@ -1444,7 +1444,7 @@
  * @ingroup API
  * @param[in] hCard Connection made from SCardConnect().
- * @param mszReaderNames [inout] Friendly name of this reader.
+ * @param mszReaderName [inout] Friendly name of this reader.
  * @param pcchReaderLen [inout] Size of the \p szReaderName multistring.
  * @param[out] pdwState Current state of this reader. \p pdwState




More information about the Pcsclite-cvs-commit mailing list